@@ -95,7 +95,7 @@ class App(object):
         for p in app_home.rglob(pattern):
             if not p.stem.startswith('_'):  # 过滤_开头的py
                 home_parts = p.parts[n:]
-                route = '/' + "/".join(home_parts)[:-3]
+                route = f'/{app_home.stem}' + "/".join(home_parts)[:-3]
                 routes.append(route)
 
                 func = importlib.import_module('.'.join(home_parts)[:-3]).main
