@@ -13,10 +13,9 @@ import time
 
 from datetime import datetime
 from typing import Optional
-from fastapi import FastAPI, Form, Depends, File, UploadFile
+from fastapi import FastAPI, Form, Depends, File, UploadFile, Body, Request, Response, Form, Cookie
 from pydantic import BaseModel
 from starlette.staticfiles import StaticFiles
-from starlette.requests import Request
 from starlette.responses import \
     RedirectResponse, FileResponse, HTMLResponse, PlainTextResponse
 from starlette.status import *
@@ -42,12 +41,37 @@ def read_root(kwargs: dict):
 def get(request: Request, xx, kwargs: dict):
     print(kwargs)
     kwargs = dict(request.query_params)
+
     print(kwargs)
     print(f"xx: {xx.split(',')}")
     return kwargs
 
+#
+# @app.api_route('/get_and_post', methods=["GET", "POST"])
+# def get_and_post(request: Request, kwargs: dict):
+#     query_params = dict(request.query_params)
+#     print("query_params:", query_params)
+#     print("kwargs:", kwargs)
+#
+#     return query_params, kwargs
+#
+
+@app.api_route('/get_and_post', methods=["GET", "POST"])
+def get_and_post(request: Request, kwargs = Body(None)):
+    print(request.method)
+    print(request.get('a'))
+    print(request.get('xxxx'))
+
+    print(request.query_params.get('a', 'xxxxx'))
+
+    query_params = dict(request.query_params)
+    print("query_params:", query_params)
+    print("kwargs:", kwargs)
+    print("path_params:", request.path_params)
+
+
 
 if __name__ == '__main__':
     import uvicorn
 
-    uvicorn.run(app)
+    uvicorn.run('raw_app:app', debug=True)
